From ab37b019b4b7509411971522875d7eafe62924d9 Mon Sep 17 00:00:00 2001
From: Kedar Sovani <kedars@marvell.com>
Date: Mon, 10 Aug 2009 08:26:05 +0200
Subject: [PATCH] s/dprintf/debug_printf/ to avoid glibc conflict.

Signed-off-by: Kedar Sovani <kedars@marvell.com>
---
 conman-0.2.2-dprintf.patch |   35 +++++++++++++++++++++++++++++++++++
 conman.spec                |    7 ++++++-
 2 files changed, 41 insertions(+), 1 deletions(-)
 create mode 100644 conman-0.2.2-dprintf.patch

diff --git a/conman-0.2.2-dprintf.patch b/conman-0.2.2-dprintf.patch
new file mode 100644
index 0000000..5a12af1
--- /dev/null
+++ b/conman-0.2.2-dprintf.patch
@@ -0,0 +1,35 @@
+diff -dupr conman_orig-0.2.2/log.c conman-0.2.2/log.c
+--- conman_orig-0.2.2/log.c	2009-08-07 16:50:50.000000000 +0530
++++ conman-0.2.2/log.c	2009-08-07 16:51:33.000000000 +0530
+@@ -61,7 +61,7 @@ static void log_aux(int errnum, int prio
+ static const char * log_prefix(int priority);
+ 
+ 
+-void dprintf(int level, const char *format, ...)
++void debug_dprintf(int level, const char *format, ...)
+ {
+     static int debug_level = -1;
+     va_list vargs;
+diff -dupr conman_orig-0.2.2/log.h conman-0.2.2/log.h
+--- conman_orig-0.2.2/log.h	2009-08-07 16:50:50.000000000 +0530
++++ conman-0.2.2/log.h	2009-08-07 16:52:10.000000000 +0530
+@@ -44,16 +44,16 @@ extern int log_daemonize_fd;
+ 
+ 
+ /*  DPRINTF((level, format, ...))
+- *    A wrapper for dprintf() allowing it to be removed from production code.
++ *    A wrapper for debug_dprintf() allowing it to be removed from production code.
+  */
+ #ifndef NDEBUG
+-#  define DPRINTF(args) dprintf args
++#  define DPRINTF(args) debug_dprintf args
+ #else /* NDEBUG */
+ #  define DPRINTF(args)
+ #endif /* !NDEBUG */
+ 
+ 
+-void dprintf(int level, const char *format, ...);
++void debug_dprintf(int level, const char *format, ...);
+ /*
+  *  Similar to printf, except output is always to stderr and only done
+  *    when 'level' is less than or equal to the "DEBUG" env var.
diff --git a/conman.spec b/conman.spec
index 8f9dbbd..36236f9 100644
--- a/conman.spec
+++ b/conman.spec
@@ -1,6 +1,6 @@
 Name:               conman
 Version:            0.2.2
-Release:            3%{?dist}
+Release:            3%{?dist}.fa1
 Summary:            ConMan - The Console Manager
 
 Group:              Applications/System
@@ -10,6 +10,7 @@ Source0:            http://download.gna.org/%{name}/%{version}/%{name}-%{version
 Source1:            %{name}.init
 Source2:            %{name}.logrotate
 BuildRoot:          %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
+Patch0:             conman-0.2.2-dprintf.patch
 
 Requires:           logrotate
 Requires(post):     /sbin/chkconfig
@@ -33,6 +34,7 @@ Its features include:
 
 %prep
 %setup -q
+%patch0 -p1 -b .dprintf
 
 %build
 # not really lib material, more like share
@@ -98,6 +100,9 @@ fi
 %{_mandir}/*/*
 
 %changelog
+* Fri Aug 07 2009 Mahavir Jain <mjain@marvell.com> - 0.2.2-3.fa1
+- Rename dprintf to debug_printf to resolve conflicts with glibc dprintf
+
 * Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2.2-3
 - Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild
 
-- 
1.5.5.6

